@@ -5,18 +5,22 @@ import logging
 import os
 import warnings
 
-from fiona import compat, vfs
-from fiona.ogrext import Iterator, ItemsIterator, KeysIterator
-from fiona.ogrext import Session, WritingSession
-from fiona.ogrext import buffer_to_virtual_file, remove_virtual_file, GEOMETRY_TYPES
-from fiona.errors import (DriverError, SchemaError, CRSError, UnsupportedGeometryTypeError, DriverSupportError)
-from fiona.logutils import FieldSkipLogFilter
-from fiona._env import get_gdal_release_name, get_gdal_version_tuple
-from fiona.env import env_ctx_if_needed
-from fiona.errors import FionaDeprecationWarning
-from fiona.drvsupport import supported_drivers
-from fiona.path import Path, vsi_path, parse_path
-from six import string_types, binary_type
+import fiona._loading
+with fiona._loading.add_gdal_dll_directories():
+    from fiona import compat, vfs
+    from fiona.ogrext import Iterator, ItemsIterator, KeysIterator
+    from fiona.ogrext import Session, WritingSession
+    from fiona.ogrext import buffer_to_virtual_file, remove_virtual_file, GEOMETRY_TYPES
+    from fiona.errors import (DriverError, SchemaError, CRSError, UnsupportedGeometryTypeError, DriverSupportError)
+    from fiona.logutils import FieldSkipLogFilter
+    from fiona._crs import crs_to_wkt
+    from fiona._env import get_gdal_release_name, get_gdal_version_tuple
+    from fiona.env import env_ctx_if_needed
+    from fiona.errors import FionaDeprecationWarning
+    from fiona.drvsupport import (supported_drivers, driver_mode_mingdal, _driver_converts_field_type_silently_to_str,
+                                  _driver_supports_field)
+    from fiona.path import Path, vsi_path, parse_path
+    from six import string_types, binary_type
 
 
 log = logging.getLogger(__name__)
@@ -74,12 +78,6 @@ class Collection(object):
         if archive and not isinstance(archive, string_types):
             raise TypeError("invalid archive: %r" % archive)
 
-        # Check GDAL version against drivers
-        if (driver == "GPKG" and get_gdal_version_tuple() < (1, 11, 0)):
-            raise DriverError(
-                "GPKG driver requires GDAL 1.11.0, fiona was compiled "
-                "against: {}".format(get_gdal_release_name()))
-
         self.session = None
         self.iterator = None
         self._len = 0
@@ -93,6 +91,17 @@ class Collection(object):
         self.ignore_fields = ignore_fields
         self.ignore_geometry = bool(ignore_geometry)
 
+        # Check GDAL version against drivers
+        if driver in driver_mode_mingdal[mode] and get_gdal_version_tuple() < driver_mode_mingdal[mode][driver]:
+            min_gdal_version = ".".join(list(map(str, driver_mode_mingdal[mode][driver])))
+
+            raise DriverError(
+                "{driver} driver requires at least GDAL {min_gdal_version} for mode '{mode}', "
+                "Fiona was compiled against: {gdal}".format(driver=driver,
+                                                            mode=mode,
+                                                            min_gdal_version=min_gdal_version,
+                                                            gdal=get_gdal_release_name()))
+
         if vsi:
             self.path = vfs.vsi_path(path, vsi, archive)
             path = parse_path(self.path)
@@ -140,14 +149,8 @@ class Collection(object):
             self._schema = schema
 
             self._check_schema_driver_support()
-
-            if crs_wkt:
-                self._crs_wkt = crs_wkt
-            elif crs:
-                if 'init' in crs or 'proj' in crs or 'epsg' in crs.lower():
-                    self._crs = crs
-                else:
-                    raise CRSError("crs lacks init or proj parameter")
+            if crs_wkt or crs:
+                self._crs_wkt = crs_to_wkt(crs_wkt or crs)
 
         self._driver = driver
         kwargs.update(encoding=encoding)
@@ -236,6 +239,10 @@ class Collection(object):
 
         Positional arguments ``stop`` or ``start, stop[, step]`` allows
         iteration to skip over items or stop at a specific item.
+
+        Note: spatial filtering using ``mask`` may be inaccurate and returning
+        all features overlapping the envelope of ``mask``.
+
         """
         if self.closed:
             raise ValueError("I/O operation on closed collection")
@@ -264,6 +271,10 @@ class Collection(object):
 
         Positional arguments ``stop`` or ``start, stop[, step]`` allows
         iteration to skip over items or stop at a specific item.
+
+        Note: spatial filtering using ``mask`` may be inaccurate and returning
+        all features overlapping the envelope of ``mask``.
+
         """
         if self.closed:
             raise ValueError("I/O operation on closed collection")
@@ -292,6 +303,9 @@ class Collection(object):
 
         Positional arguments ``stop`` or ``start, stop[, step]`` allows
         iteration to skip over items or stop at a specific item.
+
+        Note: spatial filtering using ``mask`` may be inaccurate and returning
+        all features overlapping the envelope of ``mask``.
         """
         if self.closed:
             raise ValueError("I/O operation on closed collection")
@@ -346,7 +360,7 @@ class Collection(object):
             raise IOError("collection not open for writing")
         self.session.writerecs(records, self)
         self._len = self.session.get_length()
-        self._bounds = self.session.get_extent()
+        self._bounds = None
 
     def write(self, record):
         """Stages a record for writing to disk."""
@@ -408,25 +422,23 @@ class Collection(object):
 
         for field in self._schema["properties"].values():
             field_type = field.split(":")[0]
-            if self._driver == "ESRI Shapefile":
-                if field_type == "datetime":
-                    raise DriverSupportError("ESRI Shapefile does not support datetime fields")
-                elif field_type == "time":
-                    raise DriverSupportError("ESRI Shapefile does not support time fields")
-            elif self._driver == "GPKG":
-                if field_type == "time":
-                    raise DriverSupportError("GPKG does not support time fields")
-                elif gdal_version_major == 1:
-                    if field_type == "datetime":
-                        raise DriverSupportError("GDAL 1.x GPKG driver does not support datetime fields")
-            elif self._driver == "GeoJSON":
-                if gdal_version_major == 1:
-                    if field_type == "date":
-                        warnings.warn("GeoJSON driver in GDAL 1.x silently converts date to string in non-standard format")
-                    elif field_type == "datetime":
-                        warnings.warn("GeoJSON driver in GDAL 1.x silently converts datetime to string in non-standard format")
-                    elif field_type == "time":
-                        warnings.warn("GeoJSON driver in GDAL 1.x silently converts time to string")
+
+            if not _driver_supports_field(self.driver, field_type):
+                if self.driver == 'GPKG' and gdal_version_major < 2 and field_type == "datetime":
+                    raise DriverSupportError("GDAL 1.x GPKG driver does not support datetime fields")
+                else:
+                    raise DriverSupportError("{driver} does not support {field_type} "
+                                             "fields".format(driver=self.driver,
+                                                             field_type=field_type))
+            elif field_type in {'time', 'datetime', 'date'} and _driver_converts_field_type_silently_to_str(self.driver,
+                                                                                                           field_type):
+                if self._driver == "GeoJSON" and gdal_version_major < 2 and field_type in {'datetime', 'date'}:
+                    warnings.warn("GeoJSON driver in GDAL 1.x silently converts {} to string"
+                                  " in non-standard format".format(field_type))
+                else:
+                    warnings.warn("{driver} driver silently converts {field_type} "
+                                  "to string".format(driver=self.driver,
+                                                     field_type=field_type))
 
     def flush(self):
         """Flush the buffer."""
@@ -434,7 +446,7 @@ class Collection(object):
             self.session.sync(self)
             new_len = self.session.get_length()
             self._len = new_len > self._len and new_len or self._len
-            self._bounds = self.session.get_extent()
+            self._bounds = None
 
     def close(self):
         """In append or write mode, flushes data to disk, then ends
