@@ -1,17 +1,20 @@
 # Testing collections and workspaces
 
 import datetime
+import os
+import random
 import sys
 import re
+from collections import OrderedDict
 
 import pytest
 
 import fiona
-from fiona.collection import Collection, supported_drivers
-from fiona.env import getenv
+from fiona.collection import Collection
+from fiona.env import getenv, GDALVersion
 from fiona.errors import FionaValueError, DriverError, FionaDeprecationWarning
-
-from .conftest import WGS84PATTERN
+from .conftest import WGS84PATTERN, get_temp_filename
+from fiona.drvsupport import supported_drivers, driver_mode_mingdal
 
 
 class TestSupportedDrivers(object):
@@ -858,16 +861,28 @@ def test_open_kwargs(tmpdir, path_coutwildrnp_shp):
 
 @pytest.mark.network
 def test_collection_http():
-    ds = fiona.Collection('http://raw.githubusercontent.com/OSGeo/gdal/master/autotest/ogr/data/poly.shp', vsi='http')
-    assert ds.path == '/vsicurl/http://raw.githubusercontent.com/OSGeo/gdal/master/autotest/ogr/data/poly.shp'
-    assert len(ds) == 10
+    ds = fiona.Collection(
+        "https://raw.githubusercontent.com/Toblerity/Fiona/master/tests/data/coutwildrnp.shp",
+        vsi="https",
+    )
+    assert (
+        ds.path
+        == "/vsicurl/https://raw.githubusercontent.com/Toblerity/Fiona/master/tests/data/coutwildrnp.shp"
+    )
+    assert len(ds) == 67
 
 
 @pytest.mark.network
 def test_collection_zip_http():
-    ds = fiona.Collection('http://raw.githubusercontent.com/OSGeo/gdal/master/autotest/ogr/data/poly.zip', vsi='zip+http')
-    assert ds.path == '/vsizip/vsicurl/http://raw.githubusercontent.com/OSGeo/gdal/master/autotest/ogr/data/poly.zip'
-    assert len(ds) == 10
+    ds = fiona.Collection(
+        "https://raw.githubusercontent.com/Toblerity/Fiona/master/tests/data/coutwildrnp.zip",
+        vsi="zip+https",
+    )
+    assert (
+        ds.path
+        == "/vsizip/vsicurl/https://raw.githubusercontent.com/Toblerity/Fiona/master/tests/data/coutwildrnp.zip"
+    )
+    assert len(ds) == 67
 
 
 def test_encoding_option_warning(tmpdir, caplog):
@@ -899,3 +914,51 @@ def test_collection_env(path_coutwildrnp_shp):
     """We have a GDAL env within collection context"""
     with fiona.open(path_coutwildrnp_shp):
         assert 'FIONA_ENV' in getenv()
+
+
+@pytest.mark.parametrize('driver,filename', [('ESRI Shapefile', 'test.shp'),
+                                             ('GeoJSON', 'test.json'),
+                                             ('GPKG', 'test.gpkg')])
+def test_mask_polygon_triangle(tmpdir, driver, filename):
+    """ Test if mask works for non trivial geometries"""
+    schema = {'geometry': 'Polygon', 'properties': OrderedDict([('position_i', 'int'), ('position_j', 'int')])}
+    records = [{'geometry': {'type': 'Polygon', 'coordinates': (((float(i), float(j)), (float(i + 1), float(j)),
+                                                                 (float(i + 1), float(j + 1)), (float(i), float(j + 1)),
+                                                                 (float(i), float(j))),)},
+                'properties': {'position_i': i, 'position_j': j}} for i in range(10) for j in range(10)]
+    random.shuffle(records)
+
+    path = str(tmpdir.join(filename))
+
+    with fiona.open(path, 'w',
+                    driver=driver,
+                    schema=schema,) as c:
+        c.writerecords(records)
+
+    with fiona.open(path) as c:
+        items = list(
+            c.items(mask={'type': 'Polygon', 'coordinates': (((2.0, 2.0), (4.0, 4.0), (4.0, 6.0), (2.0, 2.0)),)}))
+        assert len(items) == 15
+
+
+def test_collection__empty_column_name(tmpdir):
+    """Based on pull #955"""
+    tmpfile = str(tmpdir.join("test_empty.geojson"))
+    with pytest.warns(UserWarning, match="Empty field name at index 0"):
+        with fiona.open(tmpfile,  "w", driver="GeoJSON", schema={
+                "geometry": "Point",
+                "properties": {"": "str", "name": "str"}
+        }) as tmp:
+            tmp.writerecords([{
+                "geometry": {"type": "Point", "coordinates": [ 8, 49 ] },
+                "properties": { "": "", "name": "test" }
+            }])
+
+    with fiona.open(tmpfile) as tmp:
+        with pytest.warns(UserWarning, match="Empty field name at index 0"):
+            assert tmp.schema == {
+                "geometry": "Point",
+                "properties": {"": "str", "name": "str"}
+            }
+        with pytest.warns(UserWarning, match="Empty field name at index 0"):
+            next(tmp)
