@@ -32,7 +32,6 @@ class TestNonCountingLayer(object):
             features = self.c[2:5]
             assert len(features) == 3
 
-    def test_fail_slice_negative_index(self):
-        with pytest.warns(FionaDeprecationWarning):
-            with pytest.raises(IndexError):
-                self.c[2:-4]
+    def test_warn_slice_negative_index(self):
+        with pytest.warns((FionaDeprecationWarning, RuntimeWarning)):
+            self.c[2:-4]
